# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""carta template changes

Revision ID: 8afb44ce2d44
Revises: b586be9670d6
Create Date: 2021-08-19 15:30:15.922174

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "8afb44ce2d44"
down_revision = "b586be9670d6"
branch_labels = None
depends_on = None


script = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/
../productfetcher{{product_locator}} &
.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}

"""
ready = """To: {{destination_email}}
Subject: NRAO CARTA Session Ready


Dear User,

Your CARTA session is now available.

Please use the following link to access your CARTA session:
{{carta_url}}

You will be notified when your session has expired.

Best regards,
NRAO Workspaces

"""

expired = """To: {{destination_email}}
Subject: NRAO CARTA Session Expired


Dear User,

Your CARTA session has expired.

Thank you for using NRAO Workspaces.

Best regards,
NRAO Workspaces

"""

old_script = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

{{#need_data}}
./framework.sh -r .
cd rawdata/
../productfetcher {{product_locator}} &
.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} -d $1 -n $2 -wf $3 -r $4 {{#need_data}}&{{/need_data}}

"""
old_ready = """ To: {{destination_email}}
Subject: NRAO CARTA Session Ready


Dear User,

Your CARTA session is now available.

Please use the following link to access your CARTA session:
{{carta_url}}

You will be notified when your session has expired.

Best regards,
NRAO Workspaces

"""

old_expired = """ To: {{destination_email}}
Subject: NRAO CARTA Session Expired


Dear User,

Your CARTA session has expired.

Thank you for using NRAO Workspaces.

Best regards,
NRAO Workspaces

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script}' WHERE filename='carta.sh'
        """
    )
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{ready}' WHERE name='carta_ready'
        """
    )
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{expired}' WHERE name='carta_expired'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_script}' WHERE filename='carta.sh'
        """
    )
    op.execute(
        f"""
            UPDATE notification_templates
            SET template=E'{old_ready}' WHERE name='carta_ready'
            """
    )
    op.execute(
        f"""
            UPDATE notification_templates
            SET template=E'{old_expired}' WHERE name='carta_expired'
            """
    )
