"""supdate pims_split to use pims_analyzer

Revision ID: aaa0d28d422c
Revises: 40bd8bd55556
Create Date: 2023-03-29 11:12:06.913864

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "aaa0d28d422c"
down_revision = "40bd8bd55556"
branch_labels = None
depends_on = None

old_restore_sh = b"""#!/bin/sh
set -o errexit

export HOME={{spool_dir}}

SBIN_PATH=/lustre/aoc/cluster/pipeline/$CAPO_PROFILE/workspaces/sbin

cd {{spool_dir}}
{{^existing_restore}}
chmod 770 .
cd rawdata/
$SBIN_PATH/productfetcher --product-locator $1 --product-locator $2
cd ../
$SBIN_PATH/casa_envoy --restore -c metadata.json PPR.xml
{{/existing_restore}}
{{#existing_restore}}
$SBIN_PATH/null -n
{{/existing_restore}}
"""

new_restore_sh = b"""#!/bin/sh

export HOME={{spool_dir}}

SBIN_PATH=/lustre/aoc/cluster/pipeline/$CAPO_PROFILE/workspaces/sbin

cd {{spool_dir}}
{{^existing_restore}}
chmod 770 .
cd rawdata/
$SBIN_PATH/productfetcher --product-locator $1 --product-locator $2
cd ../
$SBIN_PATH/casa_envoy --restore -c metadata.json PPR.xml
{{/existing_restore}}
{{#existing_restore}}
$SBIN_PATH/null -n
{{/existing_restore}}
"""

old_split_sh = b"""#!/bin/sh
export HOME=$TMPDIR
TILE=$(echo $1 | cut -d "/" -f 1)
PHCENTER=$(echo $1 | cut -d "/" -f 2)

# Get the measurement set path
{{^existing_restore}}
MS={{data_location}}/working/*.ms
{{/existing_restore}}
{{#existing_restore}}
MS={{existing_restore}}
{{/existing_restore}}

# Link it in the splits rawdata
ln -s $MS rawdata/

# Run CASA
./casa_envoy --split metadata.json PPR.xml

# Populate cache
./pimscache cp -c {{vlass_product}} -t $TILE -p $PHCENTER working/*_split.ms

# If pimscache call failed, notify the user the workflow failed
if [[ $? -ne 0 ]] ; then
    # Set up for emails
    ADDRESS_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.vlassAnalystEmail"
    ADDRESS=$(./pycapo ${ADDRESS_CAPO_PROPERTY} | cut -d "'" -f 2)

    NOTIFICATION_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.serviceUrl"
    NOTIFICATION_URL=$(./pycapo ${NOTIFICATION_CAPO_PROPERTY} | cut -d "'" -f 2)/email/send

    MESSAGE="PIMS Split workflow failed in when calling:
./pimscache cp -c {{vlass_product}} -t $TILE -p $PHCENTER working/*_split.ms.

Working directory: {{data_location}}
PIMS output directory: /lustre/aoc/cluster/pipeline/vlass_$(echo $CAPO_PROFILE | cut -d '-' -f 2)/cache/pims/$1
    "

    JSON="{"destination_email": "$ADDRESS", "subject": "$SUBJECT", "message": "$MESSAGE"}"

    /bin/curl --location \
         --request POST $NOTIFICATION_URL \
         --header 'Content-Type: application/json' \
         --data-raw "$JSON"

    # Make sure we write the finished file even on failure
    /bin/date > finished
fi

# Run quicklook if second parameter was given
if ! [[ -z "$2" ]]; then
    curl --request PUT --header "Content-Length: 0" $2
fi
"""

new_split_sh = b"""#!/bin/sh
export HOME=$TMPDIR
TILE=$(echo $1 | cut -d "/" -f 1)
PHCENTER=$(echo $1 | cut -d "/" -f 2)

# Get the measurement set path
{{^existing_restore}}
MS={{data_location}}/working/*.ms
{{/existing_restore}}
{{#existing_restore}}
MS={{existing_restore}}
{{/existing_restore}}

# Link it in the splits rawdata
ln -s $MS rawdata/

# Run CASA
./casa_envoy --split metadata.json PPR.xml

# Populate cache
./pimscache cp -c {{vlass_product}} -t $TILE -p $PHCENTER working/*_split.ms

touch {{data_location}}/failed_splits.txt

# If pimscache call failed, output the failed split to a file for pims_analyzer
if [[ $? -ne 0 ]] ; then
    echo "${TILE}.${PHCENTER}" >> {{data_location}}/failed_splits.txt
fi

# Run quicklook if second parameter was given
if ! [[ -z "$2" ]]; then
    curl --request PUT --header "Content-Length: 0" $2
fi
"""

old_write_finished_file_sh = b"""#!/bin/sh
set -o errexit

cd {{data_location}}

# Set up for emails
ADDRESS_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.vlassAnalystEmail"
ADDRESS=$(./pycapo ${ADDRESS_CAPO_PROPERTY} | cut -d "'" -f 2)

NOTIFICATION_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.serviceUrl"
NOTIFICATION_URL=$(./pycapo ${NOTIFICATION_CAPO_PROPERTY} | cut -d "'" -f 2)/email/send

MESSAGE="PIMS Split workflow completed!

Working directory: {{data_location}}
PIMS output directory: /lustre/aoc/cluster/pipeline/vlass_$(echo $CAPO_PROFILE | cut -d '-' -f 2)/cache/pims/$1
"

JSON="{"destination_email": "$ADDRESS", "subject": "$SUBJECT", "message\": "$MESSAGE"}"

# Send the email
/bin/curl --location \
     --request POST $NOTIFICATION_URL \
     --header 'Content-Type: application/json' \
     --data-raw "$JSON"

/bin/date > finished
"""

new_write_finished_file_sh = b"""#!/bin/sh

cd {{data_location}}

# Set up for emails
ADDRESS_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.vlassAnalystEmail"
ADDRESS=$(./pycapo ${ADDRESS_CAPO_PROPERTY} | cut -d "'" -f 2)

NOTIFICATION_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.serviceUrl"
NOTIFICATION_URL=$(./pycapo ${NOTIFICATION_CAPO_PROPERTY} | cut -d "'" -f 2)/pims_notification/send

ANALYZER_JSON=$(./pims_analyzer --id {{request_id}} 2> analyzer_call.log)

# The analyzer call failed
if [[ $? -ne 0 ]] ; then
    FAIL_MESSAGE="Error getting metadata for pims job, check {{data_location}}/analyzer_call.log for more information"
    FAIL_SUBJECT="Failure to analyze pims_split for {{vlass_product}}"
    FAIL_JSON="{"destination_email": "$ADDRESS", "subject": "$FAIL_SUBJECT", "message\": "$FAIL_MESSAGE"}"
    FAIL_NOTIFICATION_URL=$(./pycapo ${NOTIFICATION_CAPO_PROPERTY} | cut -d "'" -f 2)/email/send

    /bin/curl --location \
         --request POST $FAIL_NOTIFICATION_URL \
         --header 'Content-Type: application/json' \
         --data-raw "$FAIL_JSON"

    exit 1
fi

# Append address information to the analyzer JSON
JSON="${ANALYZER_JSON%\\}}"destination_email": "$ADDRESS"}"

# Send the email
/bin/curl --location \
     --request POST $NOTIFICATION_URL \
     --header 'Content-Type: application/json' \
     --data-raw "$JSON"

/bin/date > finished
"""

old_write_finished_file_condor = b"""executable = write_finished_file.sh

output = write_finished.out
error = write_finished.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo
transfer_output_files = .job.ad
+nrao_output_files = "finished"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = (VLASS == True) && (HasLustre == True)
+partition = "VLASS"

queue

"""

# Need to transfer pims_analyzer into the final workflow stage
new_write_finished_file_condor = b"""executable = write_finished_file.sh

output = write_finished.out
error = write_finished.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo nraorsync://$(SBIN_PATH)/pims_analyzer
transfer_output_files = .job.ad
+nrao_output_files = "finished"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = (VLASS == True) && (HasLustre == True)
+partition = "VLASS"

queue

"""


def upgrade():
    conn = op.get_bind()
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='restore.sh'
        """,
        new_restore_sh
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='split.sh'
        """,
        new_split_sh
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='write_finished_file.sh'
        """,
        new_write_finished_file_sh
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='write_finished_file.condor'
        """,
        new_write_finished_file_condor
    )


def downgrade():
    conn = op.get_bind()
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='restore.sh'
        """,
        old_restore_sh
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='split.sh'
        """,
        old_split_sh
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='write_finished_file.sh'
        """,
        old_write_finished_file_sh
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='write_finished_file.condor'
        """,
        old_write_finished_file_condor
    )
